@@ -7,7 +7,7 @@ use Try::Tiny;
 
 use Bubblegum::Constraints -minimal;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 has 'state' => (
     is       => 'rw',
@@ -27,8 +27,12 @@ sub apply {
     my $next  = shift // $state->next;
 
     # cannot transition into unknown state
-    State::Machine::Failure->throw('Transition impossible.')
-        unless isa_string $next;
+    unless (isa_string $next) {
+        State::Machine::Failure->raise(
+            class   => 'transition/unknown',
+            message => 'Transition is unknown.',
+        );
+    }
 
     my $trans = $state->transitions->get($next);
 
@@ -39,15 +43,19 @@ sub apply {
         }
         catch {
             # transition failure
-            State::Machine::Failure->throw(
-                'Transition execution failure.'
+            State::Machine::Failure->raise(
+                class      => 'transition/execution',
+                message    => 'Transition execution failure.',
+                transition => $trans,
+                explain    => $_,
             );
         }
     }
     else {
         # transition not found
-        State::Machine::Failure->throw(
-            'Transition was not found.'
+        State::Machine::Failure->raise(
+            class   => 'transition/unknown',
+            message => 'Transition is unknown.',
         );
     }
 
@@ -76,7 +84,7 @@ State::Machine - Simple State Machine Implementation
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
